Coverage for gramex\handlers\filterhandler.py: 100%

# Coverage for gramex\handlers\filterhandler.py : 100%

## 4 statements 4 run 0 missing 0 excluded 0 partial

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 import gramex.data

2 from .formhandler import FormHandler

3

4

5 class FilterHandler(FormHandler):

6 data_filter_method = staticmethod(gramex.data.filtercols)